// coverage:ignore-file
/// FilmGyaan is an SDK that allows you to communicate with
/// https://www.themoviedb.org to get the movie/shows/people details.
/// And other stuff.
///
/// The best starting point to take a look around is the FilmGyaan class that
/// combines all available features.
library film_gyaan;

// Constants
export 'src/constants.dart' hide Constants;

// Core
export 'src/core/credentials/credentials.dart' show Credentials;
export 'src/core/endpoint.dart' hide Parameters, Result;
export 'src/core/exceptions.dart' show FilmGyaanException;
export 'src/core/logging/logging.dart' hide LazyLogger, Level, Log, ILogger;
export 'src/core/net/exceptions.dart'
    hide
        RequestTimeoutException,
        RequestCancelException,
        RequestOtherException,
        RequestFailureException;
export 'src/core/net/request_type.dart' hide RequestType;
export 'src/core/supervisor/fibre.dart' hide Fiber;
export 'src/default.dart' show FilmGyaan;

// DX
export 'src/dx/_endpoints/certifications.dart'
    hide
    CertificationsMoviesParams,
    CertificationsTvParams;
export 'src/dx/_endpoints/genre.dart'
    hide
    MoviesGenreParams,
    TvGenreParams;
export 'src/dx/_endpoints/movies.dart'
    hide
    PopularMoviesParams,
    LatestMovieParams,
    NowPlayingMoviesParams,
    UpcomingMoviesParams,
    TopRatedMoviesParams,
    MovieInformationParams,
    AlternativeTitlesParams,
    CreditsParams,
    ExternalIdsParams,
    KeywordsParams,
    MovieListsParams,
    ReleaseDatesParams,
    RecommendationsParams,
    ImagesParams,
    ReviewsParams,
    SimilarParams,
    VideosParams,
    TranslationsParams;
export 'src/dx/_endpoints/objects/alternative_titles.dart';
export 'src/dx/_endpoints/objects/certifications_list.dart';
export 'src/dx/_endpoints/objects/content_ratings.dart';
export 'src/dx/_endpoints/objects/credits.dart';
export 'src/dx/_endpoints/objects/external_ids.dart';
export 'src/dx/_endpoints/objects/genre.dart';
export 'src/dx/_endpoints/objects/genre_list.dart';
export 'src/dx/_endpoints/objects/images.dart';
export 'src/dx/_endpoints/objects/keywords.dart';
export 'src/dx/_endpoints/objects/movie_details.dart';
export 'src/dx/_endpoints/objects/movie_lists.dart';
export 'src/dx/_endpoints/objects/movies_list.dart';
export 'src/dx/_endpoints/objects/people_details.dart';
export 'src/dx/_endpoints/objects/people_images.dart';
export 'src/dx/_endpoints/objects/people_list.dart';
export 'src/dx/_endpoints/objects/people_tagged_images.dart';
export 'src/dx/_endpoints/objects/production_country.dart';
export 'src/dx/_endpoints/objects/release_dates.dart';
export 'src/dx/_endpoints/objects/review_details.dart';
export 'src/dx/_endpoints/objects/reviews_list.dart';
export 'src/dx/_endpoints/objects/spoken_language.dart';
export 'src/dx/_endpoints/objects/translations.dart';
export 'src/dx/_endpoints/objects/tv_details.dart';
export 'src/dx/_endpoints/objects/tvs_list.dart';
export 'src/dx/_endpoints/objects/videos.dart';
export 'src/dx/_endpoints/objects/watch_provider_movies.dart';
export 'src/dx/_endpoints/objects/watch_provider_regions.dart';
export 'src/dx/_endpoints/objects/watch_provider_tv.dart';
export 'src/dx/_endpoints/people.dart'
    hide
    PeopleDetailsParams,
    PeopleExternalIdParams,
    PeopleImagesParams,
    PeopleLatestParams,
    PeopleMovieCreditsParams,
    PeopleMovieTvCreditsParams,
    PeopleTaggedImagesParams,
    PeopleTranslationsParams,
    PeopleTvCreditsParams,
    PopularPersonParams;
export 'src/dx/_endpoints/reviews.dart' hide ReviewDetailsParams;
export 'src/dx/_endpoints/tv.dart'
    hide
    TvAiringTodayParams,
    TvLatestParams,
    TvPopularParams,
    TvOnAirParams,
    TvDetailsParams,
    TvTopRatedParams;
export 'src/dx/_endpoints/watch_providers.dart'
    hide
    WatchProvidersMoviesParams,
    WatchProvidersRegionsParams,
    WatchProvidersTvParams;
export 'src/dx/_utils/utils.dart' hide InvariantException;
export 'src/dx/certifications/certifications.dart' hide CertificationsDx;
export 'src/dx/genre/genre.dart' hide GenreDx;
export 'src/dx/movies/movies.dart' hide MoviesDx;
export 'src/dx/people/people.dart' hide PeopleDx;
export 'src/dx/reviews/reviews.dart' hide ReviewsDx;
export 'src/dx/tv/tv.dart' hide TvDx;
export 'src/dx/watch_providers/watch_providers.dart' hide WatchProvidersDx;

// Networking
export 'src/networking/networking.dart' hide NetworkingModule;
export 'src/networking/request_handler/request_handler.dart'
    hide RequestHandler;
export 'src/networking/response/response.dart' hide Response;
