import 'dart:io';

/// Represents a configuration for a given api key.
///
/// For making any request from film_gyan an API key has to
/// be given to the SDK.
///
/// Go to https://www.themoviedb.org/settings/api to create an API key.
///
/// Few optional parameters are also needed while making the api call.
///
/// [language] : The language in which the response has to be returned.
/// Default value is en-US. If want to use en-US no need to pass that value.
class Credentials {
  Credentials({
    required this.apiKey,
    this.language = 'en-US',
  }) {
    _region = Platform.localeName.split('_')[1];
  }

  /// API key for https://www.themoviedb.org/
  String apiKey;

  /// Language for the response
  String language;

  /// Region specific response.
  late String _region;

  /// Get the current region
  String get region => _region;
}
