import 'package:film_gyaan/core.dart';

/// An exception thrown by the Filmy Gyaan SDK.
class FilmGyaanException implements Exception {
  FilmGyaanException(
    this.message, [
    StackTrace? stackTrace,
  ]) : stackTrace = stackTrace ?? StackTrace.current;

  final String message;
  final StackTrace stackTrace;

  /// Get the complete exception details
  String exceptionDetails() => '$runtimeType: $message\n$stackTrace';

  @override
  String toString() => message;
}

/// An exception thrown when a disabled API has been requested.
class MethodDisabledException extends FilmGyaanException {
  MethodDisabledException(String message)
      : super(
          message,
        );
}

/// An exception thrown when some argument is invalid.
///
/// This may be due to:
/// - an invalid subscribe key.
/// - missing or invalid token
/// - other invalid request data.
class InvalidArgumentsException extends FilmGyaanException {
  InvalidArgumentsException([String message = Constants.invalidArgument])
      : super(
          message,
        );
}

/// An exception thrown when something unexpected happens in the SDK.
class UnknownException extends FilmGyaanException {
  UnknownException()
      : super(
          Constants.unknownError,
        );
}

/// An exception thrown when a feature is not available for particular user.
class ForbiddenException extends FilmGyaanException {
  ForbiddenException(this.service)
      : super(
          Constants.forbidden,
        );

  final String service;
}
