// coverage:ignore-file
import 'package:film_gyaan/core.dart';

/// Provides a [Request] which will contain the details for the request
/// which needs to be done.
///
/// [uri] : the other path like the endpoint
/// [headers] : headers which needs to be added to the default header of the
/// request
///
/// [body] : If any body is required to be added to the request.
///
/// [type] : Contains what is the type of the request from the [RequestType]
/// list.
class Request {
  Request.get({
    this.uri,
    this.headers,
    this.body,
  }) : type = RequestType.get;

  Request.post({
    this.uri,
    this.headers,
    this.body,
  }) : type = RequestType.post;

  Request.patch({
    this.uri,
    this.headers,
    this.body,
  }) : type = RequestType.patch;

  Request.put({
    this.uri,
    this.headers,
    this.body,
  }) : type = RequestType.put;

  Request.delete({
    this.uri,
    this.headers,
    this.body,
  }) : type = RequestType.delete;

  Request.file({
    this.uri,
    this.headers,
    this.body,
  }) : type = RequestType.file;

  RequestType type;
  Uri? uri;
  Map<String, String>? headers;
  Object? body;

  @override
  String toString() => 'Request { [$type] $uri }';
}
