// coverage:ignore-file
import 'package:film_gyaan/core.dart';

/// A class which will be used to start the request.
///
/// Also provides the response back.
///
/// [prepareUri] will be used to make the final uri
/// with the base and the request.
abstract class IRequestHandler {
  Future<IResponse> response(Request request);

  Uri prepareUri(Uri baseUri, Uri requestUri) => baseUri.replace(
        scheme: requestUri.hasScheme ? requestUri.scheme : baseUri.scheme,
        host: requestUri.host != '' ? requestUri.host : null,
        path: requestUri.path != '' ? requestUri.path : null,
        queryParameters: (baseUri.queryParameters.isNotEmpty ||
                requestUri.queryParameters.isNotEmpty)
            ? <String, dynamic>{
                if (baseUri.queryParameters.isNotEmpty)
                  ...baseUri.queryParameters,
                if (requestUri.queryParameters.isNotEmpty)
                  ...requestUri.queryParameters
              }
            : null,
      );

  bool get isCancelled;

  void cancel([dynamic reason]);
}
