// coverage:ignore-file
import 'dart:convert';

import 'package:film_gyaan/core.dart';

class MovieDetails extends Result {
  MovieDetails({
    required this.adult,
    required this.backdropPath,
    required this.genreIds,
    required this.belongsToCollection,
    required this.budget,
    required this.genres,
    required this.homepage,
    required this.id,
    required this.imdbId,
    required this.originalLanguage,
    required this.originalTitle,
    required this.overview,
    required this.popularity,
    required this.posterPath,
    required this.productionCompanies,
    required this.productionCountries,
    required this.releaseDate,
    required this.revenue,
    required this.runtime,
    required this.spokenLanguages,
    required this.status,
    required this.tagline,
    required this.title,
    required this.video,
    required this.voteAverage,
    required this.voteCount,
    required this.videos,
    required this.images,
    required this.credits,
    required this.reviews,
    required this.recommendations,
    required this.similar,
    required this.externalIds,
  });

  factory MovieDetails.fromJson(String str) => MovieDetails.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory MovieDetails.fromMap(Map<String, dynamic> json) => MovieDetails(
        adult: json['adult'] as bool? ?? false,
        genreIds: List<int>.from(
          (json['genre_ids'] as List<dynamic>? ?? <dynamic>[]).map<dynamic>(
            (dynamic x) => x as int,
          ),
        ),
        backdropPath: json['backdrop_path'] as String? ?? '',
        belongsToCollection: BelongsToCollection.fromMap(
          json['belongs_to_collection'] as Map<String, dynamic>? ??
              <String, dynamic>{},
        ),
        budget: json['budget'] as int? ?? 0,
        genres: List<Genre>.from(
          (json['genres'] as List<dynamic>? ?? <dynamic>[]).map<dynamic>(
            (dynamic x) => Genre.fromMap(
              x as Map<String, dynamic>,
            ),
          ),
        ),
        homepage: json['homepage'] as String? ?? '',
        id: json['id'] as int? ?? 0,
        imdbId: json['imdb_id'] as String? ?? '',
        originalLanguage: json['original_language'] as String,
        originalTitle: json['original_title'] as String? ?? '',
        overview: json['overview'] as String? ?? '',
        popularity: json['popularity'] as double? ?? 0,
        posterPath: json['poster_path'] as String? ?? '',
        productionCompanies: List<ProductionCompany>.from(
          (json['production_companies'] as List<dynamic>? ?? <dynamic>[])
              .map<dynamic>(
            (dynamic x) => ProductionCompany.fromMap(
              x as Map<String, dynamic>,
            ),
          ),
        ),
        productionCountries: List<ProductionCountry>.from(
          (json['production_countries'] as List<dynamic>? ?? <dynamic>[])
              .map<dynamic>(
            (dynamic x) => ProductionCountry.fromMap(
              x as Map<String, dynamic>,
            ),
          ),
        ),
        releaseDate: DateTime.tryParse(
          json['release_date'] as String? ?? '',
        ),
        revenue: json['revenue'] as int? ?? 0,
        runtime: json['runtime'] as int? ?? 0,
        spokenLanguages: List<SpokenLanguage>.from(
          (json['spoken_languages'] as List<dynamic>? ?? <dynamic>[])
              .map<dynamic>(
            (dynamic x) => SpokenLanguage.fromMap(
              x as Map<String, dynamic>,
            ),
          ),
        ),
        status: json['status'] as String? ?? '',
        tagline: json['tagline'] as String? ?? '',
        title: json['title'] as String? ?? '',
        video: json['video'] as bool? ?? false,
        voteAverage: json['voteAverage'] as double? ?? 0,
        voteCount: json['vote_count'] as int? ?? 0,
        videos: Videos.fromMap(
          json['videos'] as Map<String, dynamic>? ?? <String, dynamic>{},
        ),
        images: Images.fromMap(
          json['images'] as Map<String, dynamic>? ?? <String, dynamic>{},
        ),
        credits: Credits.fromMap(
          json['credits'] as Map<String, dynamic>? ?? <String, dynamic>{},
        ),
        reviews: ReviewsList.fromMap(
          json['reviews'] as Map<String, dynamic>? ?? <String, dynamic>{},
        ),
        recommendations: Recommendations.fromMap(
          json['recommendations'] as Map<String, dynamic>? ??
              <String, dynamic>{},
        ),
        similar: Recommendations.fromMap(
          json['similar'] as Map<String, dynamic>? ?? <String, dynamic>{},
        ),
        externalIds: ExternalIds.fromMap(
          json['external_ids'] as Map<String, dynamic>? ?? <String, dynamic>{},
        ),
      );

  bool adult;
  String backdropPath;
  BelongsToCollection belongsToCollection;
  int budget;
  List<int> genreIds;
  List<Genre> genres;
  String homepage;
  int id;
  String imdbId;
  String originalLanguage;
  String originalTitle;
  String overview;
  double popularity;
  String posterPath;
  List<ProductionCompany> productionCompanies;
  List<ProductionCountry> productionCountries;
  DateTime? releaseDate;
  int revenue;
  int runtime;
  List<SpokenLanguage> spokenLanguages;
  String status;
  String tagline;
  String title;
  bool video;
  double voteAverage;
  int voteCount;
  Videos videos;
  Images images;
  Credits credits;
  ReviewsList reviews;
  Recommendations recommendations;
  Recommendations similar;
  ExternalIds externalIds;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'adult': adult,
        'backdrop_path': backdropPath,
        'belongs_to_collection': belongsToCollection.toMap(),
        'budget': budget,
        'genres': List<Map<String, dynamic>>.from(
          genres.map<Map<String, dynamic>>(
            (x) => x.toMap(),
          ),
        ),
        'homepage': homepage,
        'id': id,
        'imdb_id': imdbId,
        'original_language': originalLanguage,
        'original_title': originalTitle,
        'overview': overview,
        'popularity': popularity,
        'poster_path': posterPath,
        'production_companies': List<Map<String, dynamic>>.from(
          productionCompanies.map<Map<String, dynamic>>(
            (x) => x.toMap(),
          ),
        ),
        'production_countries': List<Map<String, dynamic>>.from(
          productionCountries.map<Map<String, dynamic>>(
            (x) => x.toMap(),
          ),
        ),
        'release_date': releaseDate == null
            ? null
            : "${releaseDate!.year.toString().padLeft(4, '0')}-${releaseDate!.month.toString().padLeft(2, '0')}-${releaseDate!.day.toString().padLeft(2, '0')}",
        'revenue': revenue,
        'runtime': runtime,
        'spoken_languages': List<Map<String, dynamic>>.from(
          spokenLanguages.map<Map<String, dynamic>>(
            (x) => x.toMap(),
          ),
        ),
        'status': status,
        'tagline': tagline,
        'title': title,
        'video': video,
        'vote_average': voteAverage,
        'vote_count': voteCount,
        'videos': videos.toMap(),
        'images': images.toMap(),
        'credits': credits.toMap(),
        'reviews': reviews.toMap(),
        'recommendations': recommendations.toMap(),
        'similar': similar.toMap(),
        'external_ids': externalIds.toMap(),
      };
}

class BelongsToCollection {
  BelongsToCollection({
    required this.id,
    required this.name,
    required this.posterPath,
    required this.backdropPath,
  });

  factory BelongsToCollection.fromJson(String str) =>
      BelongsToCollection.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory BelongsToCollection.fromMap(Map<String, dynamic> json) =>
      BelongsToCollection(
        id: json['id'] as int? ?? 0,
        name: json['name'] as String? ?? '',
        posterPath: json['poster_path'] as String? ?? '',
        backdropPath: json['backdrop_path'] as String? ?? '',
      );

  int id;
  String name;
  String posterPath;
  String backdropPath;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'id': id,
        'name': name,
        'poster_path': posterPath,
        'backdrop_path': backdropPath,
      };
}

class ProductionCompany {
  ProductionCompany({
    required this.id,
    required this.logoPath,
    required this.name,
    required this.originCountry,
  });

  factory ProductionCompany.fromJson(String str) => ProductionCompany.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory ProductionCompany.fromMap(Map<String, dynamic> json) =>
      ProductionCompany(
        id: json['id'] as int? ?? 0,
        logoPath: json['logo_path'] as String? ?? '',
        name: json['name'] as String? ?? '',
        originCountry: json['origin_country'] as String? ?? '',
      );

  int id;
  String logoPath;
  String name;
  String originCountry;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'id': id,
        'logo_path': logoPath,
        'name': name,
        'origin_country': originCountry,
      };
}

class Recommendations {
  Recommendations({
    required this.page,
    required this.results,
    required this.totalPages,
    required this.totalResults,
  });

  factory Recommendations.fromJson(String str) => Recommendations.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory Recommendations.fromMap(Map<String, dynamic> json) => Recommendations(
        page: json['page'] as int? ?? 0,
        results: List<RecommendationsResult>.from(
          (json['results'] as List<dynamic>? ?? <dynamic>[]).map<dynamic>(
            (dynamic x) => RecommendationsResult.fromMap(
              x as Map<String, dynamic>,
            ),
          ),
        ),
        totalPages: json['total_pages'] as int? ?? 0,
        totalResults: json['total_results'] as int? ?? 0,
      );

  int page;
  List<RecommendationsResult> results;
  int totalPages;
  int totalResults;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'page': page,
        'results': List<Map<String, dynamic>>.from(
          results.map<Map<String, dynamic>>(
            (x) => x.toMap(),
          ),
        ),
        'total_pages': totalPages,
        'total_results': totalResults,
      };
}

class RecommendationsResult {
  RecommendationsResult({
    required this.adult,
    required this.backdropPath,
    required this.genreIds,
    required this.id,
    required this.mediaType,
    required this.title,
    required this.originalLanguage,
    required this.originalTitle,
    required this.overview,
    required this.popularity,
    required this.posterPath,
    required this.releaseDate,
    required this.video,
    required this.voteAverage,
    required this.voteCount,
  });

  factory RecommendationsResult.fromJson(String str) =>
      RecommendationsResult.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory RecommendationsResult.fromMap(Map<String, dynamic> json) =>
      RecommendationsResult(
        adult: json['adult'] as bool? ?? false,
        backdropPath: json['backdrop_path'] as String? ?? '',
        genreIds: List<int>.from(
          (json['genre_ids'] as List<dynamic>? ?? <dynamic>[])
              .map<dynamic>((dynamic x) => x as int),
        ),
        id: json['id'] as int? ?? 0,
        mediaType: json['media_type'] as String? ?? '',
        title: json['title'] as String? ?? '',
        originalLanguage: json['original_language'] as String? ?? '',
        originalTitle: json['original_title'] as String? ?? '',
        overview: json['overview'] as String? ?? '',
        popularity: json['popularity'] as double? ?? 0,
        posterPath: json['poster_path'] as String? ?? '',
        releaseDate: DateTime.tryParse(
          json['release_date'] as String? ?? '',
        ),
        video: json['video'] as bool? ?? false,
        voteAverage: json['popularity'] as double? ?? 0,
        voteCount: json['vote_count'] as int? ?? 0,
      );

  bool adult;
  String backdropPath;
  List<int> genreIds;
  int id;
  String mediaType;
  String title;
  String originalLanguage;
  String originalTitle;
  String overview;
  double popularity;
  String posterPath;
  DateTime? releaseDate;
  bool video;
  double voteAverage;
  int voteCount;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'adult': adult,
        'backdrop_path': backdropPath,
        'genre_ids': List<int>.from(
          genreIds.map<int>(
            (x) => x,
          ),
        ),
        'id': id,
        'media_type': mediaType,
        'title': title,
        'original_language': originalLanguage,
        'original_title': originalTitle,
        'overview': overview,
        'popularity': popularity,
        'poster_path': posterPath,
        'release_date': releaseDate == null
            ? null
            : "${releaseDate!.year.toString().padLeft(4, '0')}-${releaseDate!.month.toString().padLeft(2, '0')}-${releaseDate!.day.toString().padLeft(2, '0')}",
        'video': video,
        'vote_average': voteAverage,
        'vote_count': voteCount,
      };
}
