// coverage:ignore-file
import 'dart:convert';

import 'package:film_gyaan/core.dart';

class MoviesList extends Result {
  MoviesList({
    required this.dates,
    required this.page,
    required this.results,
    required this.totalPages,
    required this.totalResults,
  });

  factory MoviesList.fromJson(String str) => MoviesList.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory MoviesList.fromMap(Map<String, dynamic> json) => MoviesList(
        page: json['page'] as int? ?? 0,
        results: List<MovieDetails>.from(
          (json['results'] as List<dynamic>? ?? <dynamic>[]).map<dynamic>(
            (dynamic x) => MovieDetails.fromMap(
              x as Map<String, dynamic>,
            ),
          ),
        ),
        totalPages: json['total_pages'] as int? ?? 0,
        totalResults: json['total_results'] as int? ?? 0,
        dates: Dates.fromMap(
          json['dates'] as Map<String, dynamic>? ?? <String, dynamic>{},
        ),
      );

  int page;
  Dates dates;
  List<MovieDetails> results;
  int totalPages;
  int totalResults;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'page': page,
        'results': List<Map<String, dynamic>>.from(
          results.map<Map<String, dynamic>>(
            (x) => x.toMap(),
          ),
        ),
        'total_pages': totalPages,
        'total_results': totalResults,
        'dates': dates.toMap(),
      };
}

class Dates {
  Dates({
    required this.maximum,
    required this.minimum,
  });

  factory Dates.fromJson(String str) => Dates.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory Dates.fromMap(Map<String, dynamic> json) => Dates(
        maximum: DateTime.tryParse(
          json['maximum'] as String? ?? '',
        ),
        minimum: DateTime.tryParse(
          json['minimum'] as String? ?? '',
        ),
      );

  DateTime? maximum;
  DateTime? minimum;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'maximum': maximum == null
            ? null
            : "${maximum!.year.toString().padLeft(4, '0')}-${maximum!.month.toString().padLeft(2, '0')}-${maximum!.day.toString().padLeft(2, '0')}",
        'minimum': minimum == null
            ? null
            : "${minimum!.year.toString().padLeft(4, '0')}-${minimum!.month.toString().padLeft(2, '0')}-${minimum!.day.toString().padLeft(2, '0')}",
      };
}
