// coverage:ignore-file
import 'dart:convert';

import 'package:film_gyaan/core.dart';

class PeopleDetails extends Result {
  PeopleDetails({
    required this.adult,
    required this.alsoKnownAs,
    required this.biography,
    required this.birthday,
    required this.deathday,
    required this.gender,
    required this.homepage,
    required this.id,
    required this.imdbId,
    required this.knownForDepartment,
    required this.name,
    required this.placeOfBirth,
    required this.popularity,
    required this.profilePath,
    required this.combinedCredits,
    required this.externalIds,
    required this.images,
    required this.taggedImages,
    required this.knownFor,
  });

  factory PeopleDetails.fromJson(String str) => PeopleDetails.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory PeopleDetails.fromMap(Map<String, dynamic> json) => PeopleDetails(
        adult: json['adult'] as bool? ?? false,
        alsoKnownAs: List<String>.from(
          (json['also_known_as'] as List<dynamic>? ?? <dynamic>[]).map<dynamic>(
            (dynamic x) => x as String,
          ),
        ),
        biography: json['biography'] as String? ?? '',
        birthday: DateTime.tryParse(
          json['birthday'] as String? ?? '',
        ),
        deathday: DateTime.tryParse(
          json['deathday'] as String? ?? '',
        ),
        gender: json['gender'] as int? ?? 0,
        homepage: json['homepage'] as String? ?? '',
        id: json['id'] as int? ?? 0,
        imdbId: json['imdb_id'] as String? ?? '',
        knownForDepartment: json['known_for_department'] as String? ?? '',
        name: json['name'] as String? ?? '',
        placeOfBirth: json['place_of_birth'] as String? ?? '',
        popularity: json['popularity'] as double? ?? 0,
        profilePath: json['profile_path'] as String? ?? '',
        combinedCredits: CombinedCredits.fromMap(
          json['combined_credits'] as Map<String, dynamic>? ??
              <String, dynamic>{},
        ),
        externalIds: ExternalIds.fromMap(
          json['external_ids'] as Map<String, dynamic>? ?? <String, dynamic>{},
        ),
        knownFor: List<KnownFor>.from(
          (json['known_for'] as List<dynamic>? ?? <dynamic>[]).map<dynamic>(
            (dynamic x) => KnownFor.fromMap(
              x as Map<String, dynamic>,
            ),
          ),
        ),
        images: PeopleImages.fromMap(
          json['images'] as Map<String, dynamic>? ?? <String, dynamic>{},
        ),
        taggedImages: PeopleTaggedImages.fromMap(
          json['tagged_images'] as Map<String, dynamic>? ?? <String, dynamic>{},
        ),
      );

  bool adult;
  List<String> alsoKnownAs;
  String biography;
  DateTime? birthday;
  DateTime? deathday;
  int gender;
  String homepage;
  int id;
  String imdbId;
  List<KnownFor> knownFor;
  String knownForDepartment;
  String name;
  String placeOfBirth;
  double popularity;
  String profilePath;
  CombinedCredits combinedCredits;
  ExternalIds externalIds;
  PeopleImages images;
  PeopleTaggedImages taggedImages;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'adult': adult,
        'also_known_as': List<String>.from(
          alsoKnownAs.map<String>(
            (x) => x,
          ),
        ),
        'biography': biography,
        'birthday': birthday == null
            ? null
            : "${birthday!.year.toString().padLeft(4, '0')}-${birthday!.month.toString().padLeft(2, '0')}-${birthday!.day.toString().padLeft(2, '0')}",
        'deathday': deathday,
        'gender': gender,
        'homepage': homepage,
        'id': id,
        'imdb_id': imdbId,
        'known_for_department': knownForDepartment,
        'name': name,
        'place_of_birth': placeOfBirth,
        'popularity': popularity,
        'profile_path': profilePath,
        'combined_credits': combinedCredits.toMap(),
        'external_ids': externalIds.toMap(),
        'images': images.toMap(),
        'tagged_images': taggedImages.toMap(),
      };
}

class KnownFor {
  KnownFor({
    required this.adult,
    required this.backdropPath,
    required this.genreIds,
    required this.id,
    required this.mediaType,
    required this.originalLanguage,
    required this.originalTitle,
    required this.overview,
    required this.posterPath,
    required this.releaseDate,
    required this.title,
    required this.video,
    required this.voteAverage,
    required this.voteCount,
    required this.firstAirDate,
    required this.name,
    required this.originCountry,
    required this.originalName,
  });

  factory KnownFor.fromJson(String str) => KnownFor.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory KnownFor.fromMap(Map<String, dynamic> json) => KnownFor(
        adult: json['adult'] as bool? ?? false,
        backdropPath: json['backdrop_path'] as String? ?? '',
        genreIds: List<int>.from(
          (json['genre_ids'] as List<dynamic>? ?? <dynamic>[]).map<dynamic>(
            (dynamic x) => x as int,
          ),
        ),
        id: json['id'] as int? ?? 0,
        mediaType: json['media_type'] as String? ?? '',
        originalLanguage: json['original_language'] as String? ?? '',
        originalTitle: json['original_title'] as String? ?? '',
        overview: json['overview'] as String? ?? '',
        posterPath: json['poster_path'] as String? ?? '',
        releaseDate: DateTime.tryParse(
          json['release_date'] as String? ?? '',
        ),
        title: json['title'] as String? ?? '',
        video: json['video'] as bool? ?? false,
        voteAverage: json['vote_average'] as num? ?? 0,
        voteCount: json['vote_count'] as int? ?? 0,
        firstAirDate: DateTime.tryParse(
          json['first_air_date'] as String? ?? '',
        ),
        name: json['name'] as String? ?? '',
        originCountry: List<String>.from(
          (json['origin_country'] as List<dynamic>? ?? <dynamic>[])
              .map<dynamic>(
            (dynamic x) => x as String,
          ),
        ),
        originalName: json['original_name'] as String? ?? '',
      );

  bool adult;
  String backdropPath;
  List<int> genreIds;
  int id;
  String mediaType;
  String originalLanguage;
  String originalTitle;
  String overview;
  String posterPath;
  DateTime? releaseDate;
  String title;
  bool video;
  num voteAverage;
  int voteCount;
  DateTime? firstAirDate;
  String name;
  List<String> originCountry;
  String originalName;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'adult': adult,
        'backdrop_path': backdropPath,
        'genre_ids': List<String>.from(
          genreIds.map<String>(
            (x) => x as String,
          ),
        ),
        'id': id,
        'media_type': mediaType,
        'original_language': originalLanguage,
        'original_title': originalTitle,
        'overview': overview,
        'poster_path': posterPath,
        'release_date': releaseDate == null
            ? null
            : "${releaseDate!.year.toString().padLeft(4, '0')}-${releaseDate!.month.toString().padLeft(2, '0')}-${releaseDate!.day.toString().padLeft(2, '0')}",
        'title': title,
        'video': video,
        'vote_average': voteAverage,
        'vote_count': voteCount,
        'first_air_date': firstAirDate == null
            ? null
            : "${firstAirDate!.year.toString().padLeft(4, '0')}-${firstAirDate!.month.toString().padLeft(2, '0')}-${firstAirDate!.day.toString().padLeft(2, '0')}",
        'name': name,
        'origin_country': List<String>.from(
          originCountry.map<String>(
            (x) => x,
          ),
        ),
        'original_name': originalName,
      };
}

class CombinedCredits {
  CombinedCredits({
    required this.cast,
    required this.crew,
  });

  factory CombinedCredits.fromJson(String str) => CombinedCredits.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory CombinedCredits.fromMap(Map<String, dynamic> json) => CombinedCredits(
        cast: List<PersonDetailsCast>.from(
          (json['cast'] as List<dynamic>? ?? <dynamic>[]).map<dynamic>(
            (dynamic x) => PersonDetailsCast.fromMap(
              x as Map<String, dynamic>,
            ),
          ),
        ),
        crew: List<PersonDetailsCast>.from(
          (json['crew'] as List<dynamic>? ?? <dynamic>[]).map<dynamic>(
            (dynamic x) => PersonDetailsCast.fromMap(
              x as Map<String, dynamic>,
            ),
          ),
        ),
      );

  List<PersonDetailsCast> cast;
  List<PersonDetailsCast> crew;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'cast': List<Map<String, dynamic>>.from(
          cast.map<Map<String, dynamic>>(
            (x) => x.toMap(),
          ),
        ),
        'crew': List<Map<String, dynamic>>.from(
          crew.map<Map<String, dynamic>>(
            (x) => x.toMap(),
          ),
        ),
      };
}

class PersonDetailsCast {
  PersonDetailsCast({
    required this.voteAverage,
    required this.overview,
    required this.releaseDate,
    required this.adult,
    required this.backdropPath,
    required this.voteCount,
    required this.genreIds,
    required this.id,
    required this.originalLanguage,
    required this.originalTitle,
    required this.posterPath,
    required this.title,
    required this.video,
    required this.popularity,
    required this.character,
    required this.creditId,
    required this.order,
    required this.mediaType,
    required this.firstAirDate,
    required this.name,
    required this.originCountry,
    required this.originalName,
    required this.episodeCount,
    required this.department,
    required this.job,
  });

  factory PersonDetailsCast.fromJson(String str) => PersonDetailsCast.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory PersonDetailsCast.fromMap(Map<String, dynamic> json) =>
      PersonDetailsCast(
        voteAverage: json['vote_average'] as double? ?? 0,
        overview: json['overview'] as String? ?? '',
        releaseDate: json['release_date'] as String? ?? '',
        adult: json['adult'] as bool? ?? false,
        backdropPath: json['backdrop_path'] as String? ?? '',
        voteCount: json['vote_count'] as int? ?? 0,
        genreIds: List<int>.from(
          (json['genre_ids'] as List<dynamic>? ?? <dynamic>[]).map<dynamic>(
            (dynamic x) => x as int,
          ),
        ),
        id: json['id'] as int? ?? 0,
        originalLanguage: json['original_language'] as String? ?? '',
        originalTitle: json['original_title'] as String? ?? '',
        posterPath: json['poster_path'] as String? ?? '',
        title: json['title'] as String? ?? '',
        video: json['video'] as bool? ?? false,
        popularity: json['popularity'] as double? ?? 0,
        character: json['character'] as String? ?? '',
        creditId: json['credit_id'] as String? ?? '',
        order: json['order'] as int? ?? 0,
        mediaType: json['media_type'] as String? ?? '',
        firstAirDate: DateTime.tryParse(
          json['first_air_date'] as String? ?? '',
        ),
        name: json['name'] as String? ?? '',
        originCountry: List<String>.from(
          (json['origin_country'] as List<dynamic>? ?? <dynamic>[])
              .map<dynamic>(
            (dynamic x) => x as String,
          ),
        ),
        originalName: json['original_name'] as String? ?? '',
        episodeCount: json['episode_count'] as int? ?? 0,
        department: json['department'] as String? ?? '',
        job: json['job'] as String? ?? '',
      );

  double voteAverage;
  String overview;
  String releaseDate;
  bool adult;
  String backdropPath;
  int voteCount;
  List<int> genreIds;
  int id;
  String originalLanguage;
  String originalTitle;
  String posterPath;
  String title;
  bool video;
  double popularity;
  String character;
  String creditId;
  int order;
  String mediaType;
  DateTime? firstAirDate;
  String name;
  List<String> originCountry;
  String originalName;
  int episodeCount;
  String department;
  String job;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'vote_average': voteAverage,
        'overview': overview,
        'release_date': releaseDate,
        'adult': adult,
        'backdrop_path': backdropPath,
        'vote_count': voteCount,
        'genre_ids': List<String>.from(
          genreIds.map<String>(
            (x) => x as String,
          ),
        ),
        'id': id,
        'original_language': originalLanguage,
        'original_title': originalTitle,
        'poster_path': posterPath,
        'title': title,
        'video': video,
        'popularity': popularity,
        'character': character,
        'credit_id': creditId,
        'order': order,
        'media_type': mediaType,
        'first_air_date': firstAirDate == null
            ? null
            : "${firstAirDate!.year.toString().padLeft(4, '0')}-${firstAirDate!.month.toString().padLeft(2, '0')}-${firstAirDate!.day.toString().padLeft(2, '0')}",
        'name': name,
        'origin_country': List<String>.from(
          originCountry.map<String>(
            (x) => x,
          ),
        ),
        'original_name': originalName,
        'episode_count': episodeCount,
        'department': department,
        'job': job,
      };
}
