// coverage:ignore-file
import 'dart:convert';

import 'package:film_gyaan/core.dart';

class PeopleTaggedImages extends Result {
  PeopleTaggedImages({
    required this.page,
    required this.results,
    required this.totalPages,
    required this.totalResults,
    required this.id,
  });

  factory PeopleTaggedImages.fromJson(String str) => PeopleTaggedImages.fromMap(
    json.decode(str) as Map<String, dynamic>,
  );

  factory PeopleTaggedImages.fromMap(Map<String, dynamic> json) => PeopleTaggedImages(
    page: json['page'] as int? ?? 0,
    id: json['id'] as int? ?? 0,
    results: List<PeopleTaggedImagesResult>.from(
      (json['results'] as List<dynamic>? ?? <dynamic>[]).map<dynamic>(
            (dynamic x) => PeopleTaggedImagesResult.fromMap(
          x as Map<String, dynamic>,
        ),
      ),
    ),
    totalPages: json['total_pages'] as int? ?? 0,
    totalResults: json['total_results'] as int? ?? 0,
  );

  int page;
  List<PeopleTaggedImagesResult> results;
  int totalPages;
  int totalResults;
  int id;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
    'page': page,
    'results': List<Map<String, dynamic>>.from(
        results.map<Map<String, dynamic>>((x) => x.toMap())),
    'total_pages': totalPages,
    'total_results': totalResults,
    'id': id,
  };
}

class PeopleTaggedImagesResult {
  PeopleTaggedImagesResult({
    required this.aspectRatio,
    required this.filePath,
    required this.height,
    required this.id,
    required this.iso6391,
    required this.voteAverage,
    required this.voteCount,
    required this.width,
    required this.imageType,
    required this.media,
    required this.mediaType,
  });

  factory PeopleTaggedImagesResult.fromJson(String str) => PeopleTaggedImagesResult.fromMap(
    json.decode(str) as Map<String, dynamic>,
  );

  factory PeopleTaggedImagesResult.fromMap(Map<String, dynamic> json) =>
      PeopleTaggedImagesResult(
        aspectRatio: double.tryParse(
          json['aspect_ratio'] as String? ?? '',
        ) ??
            0,
        filePath: json['file_path'] as String? ?? '',
        height: json['height'] as int? ?? 0,
        id: json['id'] as String? ?? '',
        iso6391: json['iso_639_1'] as String? ?? '',
        voteAverage: double.tryParse(
          json['vote_average'] as String? ?? '',
        ) ??
            0,
        voteCount: json['vote_count'] as int? ?? 0,
        width: json['width'] as int? ?? 0,
        imageType: json['image_type'] as String? ?? '',
        media: PersonDetailsCast.fromMap(
          json['media'] as Map<String, dynamic>? ?? <String, dynamic>{},
        ),
        mediaType: json['media_type'] as String? ?? '',
      );

  double aspectRatio;
  String filePath;
  int height;
  String id;
  String iso6391;
  double voteAverage;
  int voteCount;
  int width;
  String imageType;
  PersonDetailsCast media;
  String mediaType;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
    'aspect_ratio': aspectRatio,
    'file_path': filePath,
    'height': height,
    'id': id,
    'iso_639_1': iso6391,
    'vote_average': voteAverage,
    'vote_count': voteCount,
    'width': width,
    'image_type': imageType,
    'media': media.toMap(),
    'media_type': mediaType,
  };
}