// coverage:ignore-file
import 'dart:convert';

import 'package:film_gyaan/core.dart';

class ReviewsDetails extends Result {
  ReviewsDetails({
    required this.author,
    required this.authorDetails,
    required this.content,
    required this.createdAt,
    required this.id,
    required this.updatedAt,
    required this.url,
    required this.iso_639_1,
    required this.mediaId,
    required this.mediaTitle,
  });

  factory ReviewsDetails.fromJson(String str) => ReviewsDetails.fromMap(
    json.decode(str) as Map<String, dynamic>,
  );

  factory ReviewsDetails.fromMap(Map<String, dynamic> json) => ReviewsDetails(
    author: json['author'] as String? ?? '',
    authorDetails: AuthorDetails.fromMap(
      json['author_details'] as Map<String, dynamic>? ??
          <String, dynamic>{},
    ),
    content: json['content'] as String? ?? '',
    createdAt: DateTime.tryParse(
      json['created_at'] as String? ?? '',
    ),
    id: json['id'] as String? ?? '',
    updatedAt: DateTime.tryParse(
      json['updated_at'] as String? ?? '',
    ),
    url: json['url'] as String? ?? '',
    iso_639_1: json['iso_639_1'] as String? ?? '',
    mediaId: json['media_id'] as int? ?? 0,
    mediaTitle: json['media_title'] as String? ?? '',
  );

  String author;
  AuthorDetails authorDetails;
  String content;
  DateTime? createdAt;
  String id;
  DateTime? updatedAt;
  String url;
  String iso_639_1;
  int mediaId;
  String mediaTitle;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
    'author': author,
    'author_details': authorDetails.toMap(),
    'content': content,
    'created_at': createdAt?.toIso8601String(),
    'id': id,
    'updated_at': updatedAt?.toIso8601String(),
    'url': url,
    'iso_639_1': iso_639_1,
    'media_id': mediaId,
    'media_title': mediaTitle,
  };
}

class AuthorDetails {
  AuthorDetails({
    required this.name,
    required this.username,
    required this.avatarPath,
    required this.rating,
  });

  factory AuthorDetails.fromJson(String str) => AuthorDetails.fromMap(
    json.decode(str) as Map<String, dynamic>,
  );

  factory AuthorDetails.fromMap(Map<String, dynamic> json) => AuthorDetails(
    name: json['name'] as String? ?? '',
    username: json['username'] as String? ?? '',
    avatarPath: json['avatar_path'] as String? ?? '',
    rating: json['rating'] as num? ?? 0,
  );

  String name;
  String username;
  String avatarPath;
  num rating;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
    'name': name,
    'username': username,
    'avatar_path': avatarPath,
    'rating': rating,
  };
}