// coverage:ignore-file
import 'dart:convert';

import 'package:film_gyaan/core.dart';

class Translations extends Result {
  Translations({
    required this.id,
    required this.translations,
  });

  factory Translations.fromJson(String str) => Translations.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory Translations.fromMap(Map<String, dynamic> json) => Translations(
        id: json['id'] as int? ?? 0,
        translations: List<Translation>.from(
          (json['translations'] as List<dynamic>? ?? <dynamic>[]).map<dynamic>(
            (dynamic x) => Translation.fromMap(
              x as Map<String, dynamic>,
            ),
          ),
        ),
      );

  int id;
  List<Translation> translations;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'id': id,
        'translations': List<Map<String, dynamic>>.from(
          translations.map<Map<String, dynamic>>(
            (x) => x.toMap(),
          ),
        ),
      };
}

class Translation {
  Translation({
    required this.iso31661,
    required this.iso6391,
    required this.name,
    required this.englishName,
    required this.data,
  });

  factory Translation.fromJson(String str) => Translation.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory Translation.fromMap(Map<String, dynamic> json) => Translation(
        iso31661: json['iso_3166_1'] as String? ?? '',
        iso6391: json['iso_639_1'] as String? ?? '',
        name: json['name'] as String? ?? '',
        englishName: json['english_name'] as String? ?? '',
        data: Data.fromMap(
          json['data'] as Map<String, dynamic>? ?? <String, dynamic>{},
        ),
      );

  String iso31661;
  String iso6391;
  String name;
  String englishName;
  Data data;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'iso_3166_1': iso31661,
        'iso_639_1': iso6391,
        'name': name,
        'english_name': englishName,
        'data': data.toMap(),
      };
}

class Data {
  Data({
    required this.homepage,
    required this.overview,
    required this.runtime,
    required this.tagline,
    required this.title,
    required this.biography,
  });

  factory Data.fromJson(String str) => Data.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory Data.fromMap(Map<String, dynamic> json) => Data(
        homepage: json['homepage'] as String? ?? '',
        overview: json['overview'] as String? ?? '',
        runtime: json['runtime'] as int? ?? 0,
        tagline: json['tagline'] as String? ?? '',
        title: json['title'] as String? ?? '',
    biography: json['biography'] as String? ?? '',
      );

  String homepage;
  String overview;
  int runtime;
  String tagline;
  String biography;
  String title;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'homepage': homepage,
        'overview': overview,
        'runtime': runtime,
        'tagline': tagline,
        'title': title,
        'biography': biography,
      };
}
