// coverage:ignore-file
import 'package:film_gyaan/core.dart';

/// A parameter class which will be used to make the initial request for
/// getting the details of the people.
class PeopleDetailsParams extends Parameters {
  /// [personId] : Person id of.
  PeopleDetailsParams({
    required this.personId,
  });

  int personId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/person/$personId',
          queryParameters: <String, dynamic>{
            'append_to_response':
                'combined_credits,external_ids,images,tagged_images',
          },
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the movie credits of the people.
class PeopleMovieCreditsParams extends Parameters {
  /// [personId] : Person id of.
  PeopleMovieCreditsParams({
    required this.personId,
  });

  int personId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/person/$personId/movie_credits',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the tv credits of the people.
class PeopleTvCreditsParams extends Parameters {
  /// [personId] : Person id of.
  PeopleTvCreditsParams({
    required this.personId,
  });

  int personId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/person/$personId/tv_credits',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the movie and tv credits of the people.
class PeopleMovieTvCreditsParams extends Parameters {
  /// [personId] : Person id of.
  PeopleMovieTvCreditsParams({
    required this.personId,
  });

  int personId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/person/$personId/combined_credits',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the external id of the people.
class PeopleExternalIdParams extends Parameters {
  /// [personId] : Person id of.
  PeopleExternalIdParams({
    required this.personId,
  });

  int personId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/person/$personId/external_ids',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the images of the people.
class PeopleImagesParams extends Parameters {
  /// [personId] : Person id of.
  PeopleImagesParams({
    required this.personId,
  });

  int personId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/person/$personId/images',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the tagged images of the people.
class PeopleTaggedImagesParams extends Parameters {
  /// [personId] : Person id of.
  PeopleTaggedImagesParams({
    required this.personId,
    this.page = 1,
  });

  int personId;
  int page;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/person/$personId/tagged_images',
          queryParameters: <String, dynamic>{
            'page': page.toString(),
          },
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the translations of the people.
class PeopleTranslationsParams extends Parameters {
  /// [personId] : Person id of.
  PeopleTranslationsParams({
    required this.personId,
  });

  int personId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/person/$personId/translations',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the latest people.
class PeopleLatestParams extends Parameters {
  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/person/latest',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the popular person.
class PopularPersonParams extends Parameters {
  /// [page] : Page number to get the set of person for a particular page.
  PopularPersonParams({
    this.page = 1,
  });

  int page;

  @override
  Request toRequest() => Request.get(
    uri: Uri(
      path: '/3/person/popular',
      queryParameters: <String, dynamic>{
        'page': page.toString(),
      },
    ),
  );
}
