// coverage:ignore-file
import 'package:film_gyaan/core.dart';

/// Returns the [FilmGyaanException] if any error occurs.
FilmGyaanException getExceptionFromAny(dynamic error) {
  if (error is DefaultResult) {
    return getExceptionFromDefaultResult(error);
  }

  if (error is List) {
    if (error.isEmpty) {
      return UnknownException();
    } else if (error.length == 3) {
      return FilmGyaanException(error[1] as String);
    }
  }

  return FilmGyaanException('unknown exception: $error');
}

/// Returns the [FilmGyaanException] by checking the [DefaultResult].
///
/// Like if any error happens due to invalid input to the request.
FilmGyaanException getExceptionFromDefaultResult(DefaultResult result) {
  if (result.status == 400 && result.message == 'Invalid Arguments') {
    return InvalidArgumentsException();
  }

  if (result.status == 403 &&
      result.message!.startsWith('Use of the history Delete API')) {
    return MethodDisabledException(result.message!);
  }

  if (result.status == 403 && result.message == 'Forbidden') {
    return ForbiddenException(result.message!);
  }

  if (result.message?.isNotEmpty ?? false) {
    return FilmGyaanException('Error: ${result.message}');
  }

  return FilmGyaanException(Constants.unknownError);
}
