import 'package:film_gyaan/core.dart';

final _logger = injectLogger('film_gyaan.dx.certifications');

/// A mixin for Movies which will be handling all the request made related
/// to certifications
mixin CertificationsDx on Core {
  /// Get Movie Certifications
  ///
  /// Get an up to date list of the officially supported movie
  /// certifications on TMDB.
  ///
  /// For more details on the API go [here](https://developers.themoviedb.org/3/certifications/get-movie-certifications).
  ///
  /// Throws [FilmGyaanException] on an error.
  Future<CertificationsList> getMovieCertifications() async {
    var params = CertificationsMoviesParams();

    _logger.info('Getting movie certifications');

    return defaultFlow<CertificationsMoviesParams, CertificationsList>(
      core: this,
      params: params,
      serializer: (dynamic json) => CertificationsList.fromMap(
        json as Map<String, dynamic>,
      ),
    );
  }

  /// Get Tv Certifications
  ///
  /// Get an up to date list of the officially supported tv
  /// certifications on TMDB.
  ///
  /// For more details on the API go [here](https://developers.themoviedb.org/3/certifications/get-tv-certifications).
  ///
  /// Throws [FilmGyaanException] on an error.
  Future<CertificationsList> getTvCertifications() async {
    var params = CertificationsTvParams();

    _logger.info('Getting movie certifications');

    return defaultFlow<CertificationsTvParams, CertificationsList>(
      core: this,
      params: params,
      serializer: (dynamic json) => CertificationsList.fromMap(
        json as Map<String, dynamic>,
      ),
    );
  }
}