import 'package:film_gyaan/core.dart';

final _logger = injectLogger('film_gyaan.dx.genre');

/// A mixin for Movies which will be handling all the request made related
/// to genre
mixin GenreDx on Core {
  /// Get Movie List
  ///
  /// Get the list of official genres for movies.
  ///
  /// For more details on the API go [here](https://developers.themoviedb.org/3/genres/get-movie-list).
  ///
  /// Throws [FilmGyaanException] on an error.
  Future<GenreList> getMovieGenre() async {
    var params = MoviesGenreParams();

    _logger.info('Getting movie genre');

    return defaultFlow<MoviesGenreParams, GenreList>(
      core: this,
      params: params,
      serializer: (dynamic json) => GenreList.fromMap(
        json as Map<String, dynamic>,
      ),
    );
  }

  /// Get TV List
  ///
  /// Get the list of official genres for TV shows.
  ///
  /// For more details on the API go [here](https://developers.themoviedb.org/3/genres/get-tv-list).
  ///
  /// Throws [FilmGyaanException] on an error.
  Future<GenreList> getTvGenre() async {
    var params = TvGenreParams();

    _logger.info('Getting tv genre');

    return defaultFlow<TvGenreParams, GenreList>(
      core: this,
      params: params,
      serializer: (dynamic json) => GenreList.fromMap(
        json as Map<String, dynamic>,
      ),
    );
  }
}