import 'package:film_gyaan/core.dart';

final _logger = injectLogger('film_gyaan.dx.reviews');

/// A mixin for People which will be handling all the request made related
/// to reviews
mixin ReviewsDx on Core {
  /// Get review details.
  ///
  /// Retrieve the details of a movie or TV show review.
  ///
  /// For more details on the API go [here](https://developers.themoviedb.org/3/reviews/get-review-details).
  ///
  /// Throws [FilmGyaanException] on an error.
  Future<ReviewsDetails> getReviewDetails({
    required String reviewId,
  }) async {
    Ensure(reviewId).isNotEmpty('Review id');

    var params = ReviewDetailsParams(
      reviewId: reviewId,
    );

    _logger.info('Getting details for $reviewId review');

    return defaultFlow<ReviewDetailsParams, ReviewsDetails>(
      core: this,
      params: params,
      serializer: (dynamic json) => ReviewsDetails.fromMap(
        json as Map<String, dynamic>,
      ),
    );
  }
}