import 'package:film_gyaan/core.dart';

final _logger = injectLogger('film_gyaan.dx.watch_providers');

/// A mixin for People which will be handling all the request made related
/// to watch providers
mixin WatchProvidersDx on Core {
  /// Get Available Watch Providers Regions
  ///
  /// Returns a list of all of the countries we have watch provider
  /// (OTT/streaming) data for.
  ///
  /// For more details on the API go [here](https://developers.themoviedb.org/3/watch-providers/get-available-regions).
  ///
  /// Throws [FilmGyaanException] on an error.
  Future<WatchProviderRegions> getWatchProvidersRegions() async {
    var params = WatchProvidersRegionsParams();

    _logger.info('Getting watch providers regions');

    return defaultFlow<WatchProvidersRegionsParams, WatchProviderRegions>(
      core: this,
      params: params,
      serializer: (dynamic json) => WatchProviderRegions.fromMap(
        json as Map<String, dynamic>,
      ),
    );
  }

  /// Get Available Watch Providers Movies
  ///
  /// Returns a list of the watch provider (OTT/streaming) data we have
  /// available for movies.
  ///
  /// For more details on the API go [here](https://developers.themoviedb.org/3/watch-providers/get-movie-providers).
  ///
  /// Throws [FilmGyaanException] on an error.
  Future<WatchProvidersMovie> getWatchProvidersMovie() async {
    var params = WatchProvidersMoviesParams();

    _logger.info('Getting watch providers movie');

    return defaultFlow<WatchProvidersMoviesParams, WatchProvidersMovie>(
      core: this,
      params: params,
      serializer: (dynamic json) => WatchProvidersMovie.fromMap(
        json as Map<String, dynamic>,
      ),
    );
  }

  /// Get Available Watch Providers Tv
  ///
  /// Returns a list of the watch provider (OTT/streaming) data we
  /// have available for TV series.
  ///
  /// For more details on the API go [here](https://developers.themoviedb.org/3/watch-providers/get-tv-providers).
  ///
  /// Throws [FilmGyaanException] on an error.
  Future<WatchProvidersTv> getWatchProvidersTv() async {
    var params = WatchProvidersTvParams();

    _logger.info('Getting watch providers tv');

    return defaultFlow<WatchProvidersTvParams, WatchProvidersTv>(
      core: this,
      params: params,
      serializer: (dynamic json) => WatchProvidersTv.fromMap(
        json as Map<String, dynamic>,
      ),
    );
  }
}