import 'package:film_gyaan/core.dart';
import 'package:film_gyaan/film_gyaan.dart';
import 'package:flutter_test/flutter_test.dart';

/// Testing APIs
void main() {
  var credentials = Credentials(
    apiKey: '0a2a0e42b76fc49ad24e756957b193c5',
  );

  FilmGyaan? filmyGyaan;
  var movieId = 24428;
  var personId = 1245;
  var reviewId = '4fce8f8819c29523880000de';
  var tvId = 63174;

  group(
    'Testing APIs',
    () {
      setUp(
        () {
          filmyGyaan = FilmGyaan(
            credentials: credentials,
          );
        },
      );

      group(
        'Testing Movie APIs',
        () {
          test(
            'film gyaan should not be null',
            () {
              expect(filmyGyaan != null, true);
            },
          );

          test(
            'should get the popular movie list',
            () async {
              var data = await filmyGyaan!.getPopularMovies();

              expect(data.runtimeType, MoviesList);

              movieId = data.results.first.id;
            },
          );

          test(
            'should get the now playing movie list',
            () async {
              var data = await filmyGyaan!.getNowPlaying();

              expect(data.runtimeType, MoviesList);

              movieId = data.results.first.id;
            },
          );

          test(
            'should get the upcoming movie list',
            () async {
              var data = await filmyGyaan!.getUpcomingMovies();

              expect(data.runtimeType, MoviesList);

              movieId = data.results.first.id;
            },
          );

          test(
            'should get the top rated movie list',
            () async {
              var data = await filmyGyaan!.getTopRatedMovies();

              expect(data.runtimeType, MoviesList);

              movieId = data.results.first.id;
            },
          );

          test(
            'should get the latest movie details',
            () async {
              var data = await filmyGyaan!.getLatestMovie();
              expect(data.runtimeType, MovieDetails);

              movieId = data.id;
            },
          );

          test(
            'should get the movie details',
            () async {
              var movieDetails = await filmyGyaan!.getMovieDetails(
                movieId: movieId,
              );
              expect(movieDetails.runtimeType, MovieDetails);
            },
          );

          test(
            'should get alternative movie titles',
            () async {
              var movieDetails = await filmyGyaan!.getMovieAlternativeTitles(
                movieId: movieId,
              );
              expect(movieDetails.runtimeType, AlternativeTitles);
            },
          );

          test(
            'should get credits of movie',
            () async {
              var movieDetails = await filmyGyaan!.getMovieCredits(
                movieId: movieId,
              );
              expect(movieDetails.runtimeType, Credits);
            },
          );

          test(
            'should get external ids of movie',
            () async {
              var movieDetails = await filmyGyaan!.getMovieExternalIds(
                movieId: movieId,
              );
              expect(movieDetails.runtimeType, ExternalIds);
            },
          );

          test(
            'should get images of movie',
            () async {
              var movieDetails = await filmyGyaan!.getMovieImages(
                movieId: movieId,
              );
              expect(movieDetails.runtimeType, Images);
            },
          );

          test(
            'should get keywords of movie',
            () async {
              var movieDetails = await filmyGyaan!.getMovieKeywords(
                movieId: movieId,
              );
              expect(movieDetails.runtimeType, Keywords);
            },
          );

          test(
            'should get lists of movie',
            () async {
              var data = await filmyGyaan!.getMovieLists(
                movieId: movieId,
              );
              expect(data.runtimeType, MovieLists);
            },
          );

          test(
            'should get release dates of movie',
            () async {
              var data = await filmyGyaan!.getMovieReleaseDates(
                movieId: movieId,
              );
              expect(data.runtimeType, ReleaseDates);
            },
          );

          test(
            'should get reviews of movie',
            () async {
              var data = await filmyGyaan!.getMovieReviews(
                movieId: movieId,
              );
              expect(data.runtimeType, ReviewsList);
            },
          );

          test(
            'should get similar movies of movie',
            () async {
              var data = await filmyGyaan!.getSimilarMovies(
                movieId: movieId,
              );
              expect(data.runtimeType, MoviesList);
            },
          );

          test(
            'should get recommended movies of movie',
            () async {
              var data = await filmyGyaan!.getMovieRecommendations(
                movieId: movieId,
              );
              expect(data.runtimeType, MoviesList);
            },
          );

          test(
            'should get translations of movie',
            () async {
              var data = await filmyGyaan!.getMovieTranslations(
                movieId: movieId,
              );
              expect(data.runtimeType, Translations);
            },
          );

          test(
            'should get videos of movie',
            () async {
              var data = await filmyGyaan!.getMovieVideos(
                movieId: movieId,
              );
              expect(data.runtimeType, Videos);
            },
          );
        },
      );

      group(
        'Testing Person APIs',
        () {
          test(
            'should get popular people',
            () async {
              var data = await filmyGyaan!.getPopularPeople();
              expect(data.runtimeType, PeopleList);

              personId = data.results.first.id;
            },
          );

          test(
            'should get latest person',
            () async {
              var data = await filmyGyaan!.getLatestPerson();
              expect(data.runtimeType, PeopleDetails);

              personId = data.id;
            },
          );

          test(
            'should get person details',
            () async {
              var data = await filmyGyaan!.getPersonDetails(
                personId: personId,
              );

              expect(data.runtimeType, PeopleDetails);
            },
          );

          test(
            'should get person movie credits',
            () async {
              var data = await filmyGyaan!.getPersonMovieCredits(
                personId: personId,
              );

              expect(data.runtimeType, Credits);
            },
          );

          test(
            'should get person tv credits',
            () async {
              var data = await filmyGyaan!.getPersonTvCredits(
                personId: personId,
              );

              expect(data.runtimeType, Credits);
            },
          );

          test(
            'should get person combined credits',
            () async {
              var data = await filmyGyaan!.getPersonCombinedCredits(
                personId: personId,
              );

              expect(data.runtimeType, Credits);
            },
          );

          test(
            'should get person external ids',
            () async {
              var data = await filmyGyaan!.getPersonExternalId(
                personId: personId,
              );

              expect(data.runtimeType, ExternalIds);
            },
          );

          test(
            'should get person images',
            () async {
              var data = await filmyGyaan!.getPersonImages(
                personId: personId,
              );

              expect(data.runtimeType, PeopleImages);
            },
          );

          test(
            'should get person tagged images',
            () async {
              var data = await filmyGyaan!.getPersonTaggedImages(
                personId: personId,
              );

              expect(data.runtimeType, PeopleTaggedImages);
            },
          );

          test(
            'should get person translations',
            () async {
              var data = await filmyGyaan!.getPersonTranslations(
                personId: personId,
              );

              expect(data.runtimeType, Translations);
            },
          );
        },
      );

      group(
        'Testing Certifications APIs',
        () {
          test(
            'should get movie certifications',
            () async {
              var data = await filmyGyaan!.getMovieCertifications();

              expect(data.runtimeType, CertificationsList);
            },
          );

          test(
            'should get tv certifications',
            () async {
              var data = await filmyGyaan!.getTvCertifications();

              expect(data.runtimeType, CertificationsList);
            },
          );
        },
      );

      group(
        'Testing Review APIs',
        () {
          test(
            'should get details',
            () async {
              var data = await filmyGyaan!.getReviewDetails(
                reviewId: reviewId,
              );

              expect(data.runtimeType, ReviewsDetails);
            },
          );
        },
      );

      group(
        'Testing Watch Providers APIs',
        () {
          test(
            'should get region list',
            () async {
              var data = await filmyGyaan!.getWatchProvidersRegions();

              expect(data.runtimeType, WatchProviderRegions);
            },
          );

          test(
            'should get movie list',
            () async {
              var data = await filmyGyaan!.getWatchProvidersMovie();

              expect(data.runtimeType, WatchProvidersMovie);
            },
          );

          test(
            'should get tv list',
            () async {
              var data = await filmyGyaan!.getWatchProvidersTv();

              expect(data.runtimeType, WatchProvidersTv);
            },
          );
        },
      );

      group(
        'Testing Genre APIs',
        () {
          test(
            'should get movie genre',
            () async {
              var data = await filmyGyaan!.getMovieGenre();

              expect(data.runtimeType, GenreList);
            },
          );

          test(
            'should get tv genre',
            () async {
              var data = await filmyGyaan!.getTvGenre();

              expect(data.runtimeType, GenreList);
            },
          );
        },
      );

      group(
        'Testing TV APIs',
        () {
          test(
            'should get airing today',
            () async {
              var data = await filmyGyaan!.getTvAiringToday();

              expect(data.runtimeType, TvsList);
              tvId = data.results.first.id;
            },
          );

          test(
            'should get on air',
            () async {
              var data = await filmyGyaan!.getTvOnTheAir();

              expect(data.runtimeType, TvsList);
              tvId = data.results.first.id;
            },
          );

          test(
            'should get top rated',
            () async {
              var data = await filmyGyaan!.getTvTopRated();

              expect(data.runtimeType, TvsList);
              tvId = data.results.first.id;
            },
          );

          test(
            'should get popular',
            () async {
              var data = await filmyGyaan!.getTvPopular();

              expect(data.runtimeType, TvsList);
              tvId = data.results.first.id;
            },
          );

          test(
            'should get latest',
            () async {
              var data = await filmyGyaan!.getTvLatest();

              expect(data.runtimeType, TvDetails);
              tvId = data.id;
            },
          );

          test(
            'should get details',
            () async {
              var data = await filmyGyaan!.getTvDetails(
                tvId: tvId,
              );

              expect(data.runtimeType, TvDetails);
            },
          );

          test(
            'should get aggregated credits',
            () async {
              var data = await filmyGyaan!.getTvAggregateCredits(
                tvId: tvId,
              );

              expect(data.runtimeType, Credits);
            },
          );

          test(
            'should get alternative titles',
            () async {
              var data = await filmyGyaan!.getTvAlternativeTitles(
                tvId: tvId,
              );

              expect(data.runtimeType, AlternativeTitles);
            },
          );

          test(
            'should get content ratings',
            () async {
              var data = await filmyGyaan!.getTvContentRatings(
                tvId: tvId,
              );

              expect(data.runtimeType, ContentRatings);
            },
          );
        },
      );
    },
  );
}
